@@ -18,6 +18,7 @@ class ERMLPEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
                              ] = "Stochastic Local Closed World Assumption",
         verbose: bool = False,
         random_state: int = 42,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new PyKEEN ERMLPE model.
@@ -51,6 +52,8 @@ class ERMLPEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             Whether to show loading bars.
         random_state: int = 42
             Random seed to use while training the model
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -63,6 +66,7 @@ class ERMLPEPyKEEN(EntityRelationEmbeddingModelPyKEEN):
             training_loop=training_loop,
             verbose=verbose,
             random_state=random_state,
+            ring_bell=ring_bell,
             enable_cache=enable_cache
         )
 
