@@ -35,6 +35,7 @@ class PyKEENEmbedder(AbstractEmbeddingModel):
                              ] = "Stochastic Local Closed World Assumption",
         verbose: bool = False,
         random_state: int = 42,
+        ring_bell: bool = False,
         enable_cache: bool = False
     ):
         """Create new PyKEEN Abstract Embedder model.
@@ -60,6 +61,8 @@ class PyKEENEmbedder(AbstractEmbeddingModel):
             Whether to show the loading bar.
         random_state: int = 42
             Random seed to use while training the model
+        ring_bell: bool = False,
+            Whether to play a sound when embedding completes.
         enable_cache: bool = False
             Whether to enable the cache, that is to
             store the computed embedding.
@@ -93,6 +96,7 @@ class PyKEENEmbedder(AbstractEmbeddingModel):
         super().__init__(
             embedding_size=embedding_size,
             enable_cache=enable_cache,
+            ring_bell=ring_bell,
             random_state=random_state
         )
 
